import { axios } from '@/utils/request'
import { stringify } from 'qs'

/**
 * page func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function getScrapPage (parameter) {
  return axios({
    url: '/sb/scraps/page?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * add func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function addScrap (parameter) {
  return axios({
    url: '/sb/scraps',
    method: 'POST',
    headers: {
      'Accept': 'application/json',
      'Content-Type': 'application/json;charset=UTF-8'
    },
    data: parameter
  })
}

/**
 * update func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function updateScrap (parameter) {
  return axios({
    url: '/sb/scraps/' + parameter.id,
    method: 'PUT',
    data: parameter
  })
}

/**
 * submit func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function submit (parameter) {
  return axios({
    url: '/sb/scraps/' + parameter.id + '/submit',
    method: 'PUT'
  })
}

/**
 * audit func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function audit (parameter) {
  return axios({
    url: '/sb/scraps/' + parameter.id + '/audit',
    method: 'PUT',
    data: parameter
  })
}

/**
 * close func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function close (parameter) {
  return axios({
    url: '/sb/scraps/' + parameter.id + '/close',
    method: 'PUT',
    data: parameter
  })
}

/**
 * fetch single func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function fetchScrap (parameter) {
  return axios({
    url: '/sb/scraps/' + parameter.id,
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * query list func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function queryScrap (parameter) {
  return axios({
    url: '/sb/scraps?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * delete batch func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function deleteScraps (parameter) {
  return axios({
    url: '/sb/scraps',
    method: 'DELETE',
    data: parameter
  })
}

/**
 * delete single func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function deleteScrap (parameter) {
  return axios({
    url: '/sb/scraps/' + parameter.id,
    method: 'DELETE',
    data: parameter
  })
}

/**
 * export file
 * parameter: { }
 * @param parameter :
 * @returns {*}
 */
export function exportScrap (parameter) {
  return axios({
    url: '/sb/scraps/export?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    },
    responseType: 'blob'
  })
}
