import { axios } from '@/utils/request'
import { stringify } from 'qs'

/**
 * add batch func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function changeStore (parameter) {
  return axios({
    url: '/store/stores/change',
    method: 'POST',
    headers: {
      'Accept': 'application/json',
      'Content-Type': 'application/json;charset=UTF-8'
    },
    data: parameter
  })
}

/**
 * page func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function getStorePage (parameter) {
  return axios({
    url: '/store/stores/page?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * add func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function addStore (parameter) {
  return axios({
    url: '/store/stores',
    method: 'POST',
    headers: {
      'Accept': 'application/json',
      'Content-Type': 'application/json;charset=UTF-8'
    },
    data: parameter
  })
}

/**
 * update func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function updateStore (parameter) {
  return axios({
    url: '/store/stores/' + parameter.id,
    method: 'PUT',
    data: parameter
  })
}

/**
 * fetch single func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function fetchStore (parameter) {
  return axios({
    url: '/store/stores/' + parameter.id,
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * query list func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function queryStore (parameter) {
  return axios({
    url: '/store/stores?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * query list func
 * 根据登录用户所属项目，获取项目所属仓库
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function queryByLoginUserDept (parameter) {
  return axios({
    url: '/store/stores/dept?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * delete batch func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function deleteStores (parameter) {
  return axios({
    url: '/store/stores',
    method: 'DELETE',
    data: parameter
  })
}

/**
 * delete single func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function deleteStore (parameter) {
  return axios({
    url: '/store/stores/' + parameter.id,
    method: 'DELETE',
    data: parameter
  })
}

/**
 * export file
 * parameter: { }
 * @param parameter :
 * @returns {*}
 */
export function exportStore (parameter) {
  return axios({
    url: '/store/stores/export?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    },
    responseType: 'blob'
  })
}

/**
 * 获取树
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function fetchStoreTree (parameter) {
  return axios({
    url: '/store/stores/tree?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * 获取树
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function fetchStoreTableTree (parameter) {
  return axios({
    url: '/store/stores/tableTree?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * add batch func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function importStore (parameter) {
  return axios({
    url: '/store/stores/import',
    method: 'POST',
    headers: {
      'Accept': 'application/json',
      'Content-Type': 'application/json;charset=UTF-8'
    },
    data: parameter
  })
}
